+++
title= "THE NEW DIGITAL TOKEN CRAZE THAT’S SHAKING UP THE ART WORLD"
date = "2021-08-16T00:04:55+08:00"
tags = ["NFT"]
type = "blog"
categories = ["NFT"]
banner = "https://miro.medium.com/max/1200/1*iWdjxUAKW0gdXxwhOyLWDw.jpeg"
+++

In February, 32-year-old entrepreneur Jessie Schwarz purchased a non-fungible token (NFT) of an NBA Top Shot video clip of a dunk by basketball superstar LeBron James for $208,000, along with some friends, and paid for it using FLOW tokens. By doing so, Schwarz is now the owner of a token that certifies he rightfully owns that specific video clip, even though anyone can watch the clip on NBA Top Shot, or indeed on YouTube, for free.

Mr. Schwarz’s purchase represents just one of many forays into NFTs that investors have made this year, purchasing digital collectibles for seemingly extortionate amounts that veered into the tens of millions of dollars. Other examples include Twitter’s chief executive officer, Jack Dorsey, selling his first-ever tweet as a newly minted NFT for 1,630.6 ether, the digital currency of the Ethereum blockchain, which at the time was equivalent to $2.9 million; the sale by electronic music producer 3LAU (Justin David Blau) of a collection of limited edition NFTs for $3,666,666, which brought his NFT sales of 33 unique items in total to some $11,684,101; and a 10-second video artwork by the artist Beeple (Mike Winkelmann) that sold for a cool $6.6 million. So, what is driving the extraordinary craze for these NFTs?

But first, the basics. NFT stands for _non-fungible token_. In some ways, NFTs are similar to cryptocurrencies and digital assets such as bitcoin and ether, to which the world has increasingly become accustomed. But they are also different in several crucially important ways. Primarily, the main difference is that an NFT is tied to the value of a specific asset, such as a digital artwork, and thus serves as a certification of ownership of the asset. CryptoPunks was among the first NFTs to be released on Ethereum—and remains hugely popular today. This project has been influential in the development of NFTs, particularly with respect to digital art, with all of the 10,000 CryptoPunks characters in existence designed to be different from one another through their underlying codes.

The non-fungibility of NFTs, moreover, means that they are in scarce supply; although one bitcoin has no discerning difference from another, an NFT is one of a kind with very limited availability. This uniqueness underpins much of their lofty valuations, as they can’t be exchanged like-for-like. As such, an NFT acts as a digital document of the asset’s authenticity and ownership that can’t be replaced or changed.

The popular cryptocurrency news publication CoinDesk also highlights four additional characteristic properties that NFTs typically possess:

1.  **Non-interoperable:** As an example, CryptoPunks cannot be used as characters on the CryptoKitties game—another popular project based on collectible digital cats—or vice versa. This also applies to collectibles such as trading cards.
2.  **Indivisible:** Each NFT exists as a whole token and thus can’t be divided into smaller denominations, unlike cryptocurrencies such as bitcoin satoshis.
3.  **Indestructible:** By using the blockchain and smart contracts to secure all stored data related to each NFT, a token cannot be destroyed, removed or replicated. Immutable NFT ownership also means those who purchase such tokens are their rightful owners rather than the companies that created them (unlike music-streaming services, where users purchase a license to listen to the music rather than owning the music itself).
4.  **Verifiable:** The use of blockchain technology means that historical ownership data can be traced back to the original creator, thus enabling pieces to be authenticated without the need for an external third party.

Indeed, most NFTs are issued and traded on the Ethereum blockchain as an ERC-721 Non-Fungible Token Standard. This type of token can store more information pertaining to the asset that the NFT represents and thus operates quite differently from an ERC-20 token, which is the typical standard used for all smart contracts on the Ethereum blockchain for token implementation.

Such characteristics elevate NFTs above standard cryptocurrencies and enable them to be used for virtually anything that can be stored digitally, such as gameplay, music files and digital art. Indeed, it is the latter that arguably is the most fascinating use case for NFTs, especially given the disruptive impact NFTs are having on the global art industry. Indeed, with the advancements made in distributed ledger technologies, digital collectors can possess the immutable ownership of assets such as art, while investors can also seek to profit from them just like any other asset class.

There are material benefits of using the NFT method. For creators, they can sell their works directly to buyers without involving intermediaries in the process. This improved transaction efficiency allows creators to retain more profits and prevents buyers from paying fees at their ends. What’s more, artists can receive more royalties from NFTs as they can be programmed into their digital artworks, thus enabling them to receive shares of sales whenever their works are sold on to other buyers. “It’s chill. It’s easy to buy, it’s easy to sell, it’s easy to hold, it’s easy to look at on your phone,” US entrepreneur and NFT- and crypto-enthusiast Mark Cuban recently said. “We value things that are digital. It doesn’t have to be only physical any longer.”

With such considerations in mind, even the most respected names from the art industry are getting involved in the NFT craze. Auction house Sotheby’s is among the latest to announce its entry into the market through its collaboration with digital artist Pak and specialist NFT marketplace Nifty Gateway with the sale of The Fungible Collection, a “novel collection of digital art redefining our understanding of value”, for more than $17 million. Nifty Gateway also hosted an auction that included a digital illustration by Beeple, whose digital work “Everydays: the First 5000 Days” was sold by Christie’s for a whopping $69.3 million. The buyer, Singapore-based crypto enthusiast Vignesh Sundaresan (also known as MetaKovan), is the founder of Metapurse, a cryptocurrency fund that launched the public-art project B.20 earlier this year that seeks to transform “the experience and ownership of art” and contains 20 Beeple NFTs purchased in December.

With such activity being witnessed, it is no surprise that NFTs have experienced a massive boom this year, with some digital artworks selling for mind-bogglingly expensive figures. Indeed, sales of such tokens surged to an enormous $2 billion in the first quarter of this year, according to figures from NonFungible.com, which is some 20 times more than 2020’s final quarter. The NFT tracking site also noted that there were more than twice as many buyers than sellers in the first quarter—73,000 buyers versus 33,000 sellers, further underlining the bullish sentiment in the NFT market at present. According to the company, it is “a signal of massive interest in newcomers, but also of the desire of current owners to keep their assets, which creates a phenomenon of scarcity in the market”.

But as has been the case across the broader cryptocurrency complex, as well as other markets such as equities and special purpose acquisition companies (SPACs), discussion abounds over whether NFTs have already entered bubble territory. Even Beeple himself admitted as much, telling popular crypto news outlet CoinDesk, “I think it’s a bubble…. If it’s not a bubble now, I do believe it probably will be a bubble at some point, because there’s just so many people rushing into this space.” He also acknowledged to CNN in March that he “might be the big winner” of the bubble. However, it must also be observed that the current NFT market capitalisation of around $30 billion is just a fraction compared to other perceived bubbles of recent times, suggesting there is more room for investors to enter going forward. “The aggregate value of NFT platform tokens is worth 2x more than Squarespace. Is that a bubble?” Ikigai Asset Management’s Travis Kling tweeted in late April.

Another concern when it comes to NFTs is the environmental impact that results from minting such tokens. Each Ethereum transaction’s carbon footprint is currently more than 40 kilograms of CO2 (carbon dioxide), according to Digiconomist, which provides an Ethereum Energy Consumption Index. With consistently more computing power required per transaction, more resources are used up. And while “green” NFTs are now gradually increasing in circulation, they represent a small fraction of the NFT landscape. As is the case with most cryptocurrencies that utilise a “proof-of-work” blockchain-consensus mechanism, such as bitcoin and ether, environmental considerations are given alarmingly little attention.

Nonetheless, for artists keen to enter the digital space, NFTs could end up being a goldmine—or, perhaps, at least a way for them to earn a decent standard of living. They also facilitate direct, more intimate relationships between artists and their supporters by eliminating the need for middleman brokers to be involved in transactions. And as a relatively new marketplace, there will undoubtedly be an evolving process of price discovery during the coming months. As with all things crypto and token-related, how the space matures and becomes more legitimate will be particularly interesting to observe.